"""
Easily install and update centralized pre-commit hooks and their configuration files
in decentralized repositories.
"""

from centralized_pre_commit_conf.install import install

__version__ = "0.4.0"

__all__ = ["install"]
